--
-- lexion600
-- Specialization for lexion600
--
-- @author:		Michi77
-- @date:		10/07/16
-- @version:	v1.5
-- @history:	v1.0 - initial version
--				v1.5 - bug fixes, achievement, 
--
-- free for non-commercial usage

lexion600 = {};

function lexion600.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Combine, specializations);
end;

function lexion600:load(xmlFile)
	self.playAddAnimation = SpecializationUtil.callSpecializationsFunction("playAddAnimation");
	self.changeChopperWidth = SpecializationUtil.callSpecializationsFunction("changeChopperWidth");
	--self.saveInitialValues = Utils.overwrittenFunction(AchievementManager.saveInitialValues, lexion600.saveInitialValues);
	
	self.indoorIndex = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.myPipe#index"));
	
	self.didAnimation = true;
	self.chopperSName = getXMLString(self.xmlFile, "vehicle.additionalChopper.chopperS#name");
	self.chopperMName = getXMLString(self.xmlFile, "vehicle.additionalChopper.chopperM#name");
	self.chopperLName = getXMLString(self.xmlFile, "vehicle.additionalChopper.chopperL#name");
	self.chopperSL10n = getXMLString(self.xmlFile, "vehicle.additionalChopper.chopperS#l10n");
	self.chopperML10n = getXMLString(self.xmlFile, "vehicle.additionalChopper.chopperM#l10n");
	self.chopperLL10n = getXMLString(self.xmlFile, "vehicle.additionalChopper.chopperL#l10n");
	self.chopperAnimName = self.chopperSName;
	self:changeChopperWidth(self.chopperSName, false);
	self.currentAnim = 0;
	self.currentl10n = self.chopperSL10n;
	g_currentMission.hasLexion = 1;
	self.archievementGot = false;
	
	local file = g_modsDirectory.."/../achievements.xml";
	if fileExists(file) then
		achievements = loadXMLFile("achievements", file, "achievements");
		self.archievementGot = getXMLBool(achievements, "Achievements.Lexion#state");
		saveXMLFile(achievements);	
	else --create std file instead:
		achievements = createXMLFile("achievements", file, "achievements");
		setXMLBool(achievements, "Achievements.Lexion#state",true);
		saveXMLFile(achievements);
	end;
	
	if not self.archievementGot then
		g_achievementManager:addAchievement(17, "Lexion", "Fahre mit einem Claas Lexion", "Vielen Dank für's Herunterladen des Claas Lexion Packs!", 0, 1, false, Utils.getFilename("hud/achievement_lexion.png", self.baseDirectory));
	end;
	--table.getn(g_achievementManager.achievementListByName)+1
end;


lexion600.saveInitialValues = function (self)
	if g_currentMission.missionInfo.isNewSPCareer then
		self.startMoney = nil
		self.startLoan = nil
		self.startTraveledDistanceTotal = nil
		self.startPlayTime = nil
		self.startHectaresThreshedTotal = nil
		self.startHectaresSeededTotal = nil
		self.startGoldCoinCount = nil
		self.startCompletedMissions = nil
		self.startBankruptcy = nil
		self.startLexion = nil
	else
		self.startMoney = g_currentMission.missionStats.money
		self.startLoan = -g_currentMission.missionStats.loan
		self.startTraveledDistanceTotal = g_currentMission.missionStats:getTotalValue("traveledDistance")
		self.startPlayTime = math.floor(g_currentMission.missionStats:getTotalValue("playTime")/60 + 0.0001)
		self.startHectaresThreshedTotal = g_currentMission.missionStats:getTotalValue("hectaresThreshed")
		self.startHectaresSeededTotal = g_currentMission.missionStats:getTotalValue("hectaresSeeded")
		self.startFoundGoldCoinCount = g_currentMission.missionStats:getTotalValue("foundGoldCoinCount")
		self.startCompletedMissions = g_currentMission.missionStats:getCompletedMissions()
		self.startBankruptcy = 0
		self.startLexion = g_currentMission.hasLexion

		if g_currentMission.missionStats.money < 0 and g_currentMission.environment.currentDay == 1 then
			self.startBankruptcy = 1
		end
	end

	return 
end

function lexion600:mouseEvent(posX, posY, isDown, isUp, button)
end;

function lexion600:keyEvent(unicode, sym, modifier, isDown)
end;

function lexion600:update(dt)
	if self.didAnimation ~= self.isStrawEnabled then
		self.didAnimation = self.isStrawEnabled;
		self:playAddAnimation(self.isStrawEnabled, false, false);
	end;
	if not self.archievementGot then
		if g_currentMission ~= nil and g_currentMission.missionInfo:isa(FSCareerMissionInfo) and not g_currentMission.missionDynamicInfo.isMultiplayer and g_currentMission.gameStarted then
			g_achievementManager.achievementTimer = g_achievementManager.achievementTimer + dt


			if g_achievementManager.achievementTimeInterval <= g_achievementManager.achievementTimer then
				g_achievementManager:handleStandardScoreAchievement("Lexion", g_currentMission.hasLexion, self.startLexion);
				
				g_achievementManager.achievementTimer = 0;
			end
		end
	end;
end;

function lexion600:updateTick(dt)
	--[[if self:getIsActiveForInput(false) and not self:hasInputConflictWithSelection() then
		if self:getToggledFoldDirection() ~= self.turnOnFoldDirection then
			self.chopperSwitchAvailable = true;
		else
			--self.toggleChopperWarningTime = g_currentMission.time + 2000;
			self.chopperSwitchAvailable = false;
		end;
	end;]]
end;

function lexion600:draw()
	if self.currentAnim == 0 then
		self.currentl10n = self.chopperSL10n;
	elseif self.currentAnim == 1 then
		self.currentl10n = self.chopperML10n;
	else
		self.currentl10n = self.chopperLL10n;
	end;
end;

function lexion600:delete()
end;

function lexion600:readStream(streamId, connection)
    --local cw = streamReadString(streamId);
	--self:changeChopperWidth(cw, true);
end;

function lexion600:writeStream(streamId, connection)   
	--streamWriteString(streamId, self.chopperAnimName);
end;

function lexion600:startThreshing()
	self:playAddAnimation(self.isStrawEnabled, false, false);
end;

function lexion600:stopThreshing()
	self:playAddAnimation(self.isStrawEnabled, false, false);
end;

function lexion600:changeChopperWidth(name, noEventSend)
	self.chopperAnimName = name;
	self:playAddAnimation(self.isStrawEnabled, false, false);
	--SetChopperWidth.sendEvent(self, name, noEventSend);
end;

function lexion600:playAddAnimation(isStrawEnabled, noEventSend, force) 
    if self:getIsActive() then 
        if self:getIsTurnedOn() then 
			if self.playAnimation ~= nil and self.chopperAnimName ~= nil then 
				local dir = -1; 
				self:stopAnimation(self.chopperSName, true);
				self:stopAnimation(self.chopperMName, true);
				self:stopAnimation(self.chopperLName, true);
				self:playAnimation(self.chopperAnimName, 1, nil, true); 
			end;
		else
			self:stopAnimation(self.chopperSName, true);
			self:stopAnimation(self.chopperMName, true);
			self:stopAnimation(self.chopperLName, true);
			self:stopAnimation(self.chopperAnimName, true);
		end;
	else
		self:stopAnimation(self.chopperSName, true);
		self:stopAnimation(self.chopperMName, true);
		self:stopAnimation(self.chopperLName, true);
		self:stopAnimation(self.chopperAnimName, true);
	end;
end;
-- converted